#!c:\ci_311\gdal-split_1678327835246\_h_env\python.exe
# EASY-INSTALL-SCRIPT: 'GDAL==3.6.2','pct2rgb.py'
__requires__ = 'GDAL==3.6.2'
__import__('pkg_resources').run_script('GDAL==3.6.2', 'pct2rgb.py')
